/*
 * PCB Exposure Timer, hal.h
 *
 * (c) Axel (XL) Schwenke, axel.schwenke@gmx.net
 *
 * $Id: hal.h 192 2012-10-30 22:23:28Z schwenke $
 *
 *
 *    AT90S2313
 * ---------------------------------
 *  1 Reset - ISP, 10K pullup to Vcc
 *  2 PD0   - NSM4202, /OE
 *  3 PD1   - NSM4202, CLK
 *  4 Xtal1 - Xtal, 22p to GND
 *  5 Xtal2 - Xtal, 22p to GND
 *  6 PD2   - NSM4202, DATA
 *  7 PD3
 *  8 PD4   - Bulb Switch, H=on
 *  9 PD5
 * 10 GND   - GND
 * 11 PD6   - Encoder, Push-Button
 * 12 PB0   - Encoder, A
 * 13 PB1   - Encoder, B
 * 14 PB2
 * 15 PB3
 * 16 PB4
 * 17 MOSI  - ISP
 * 18 MISO  - ISP
 * 19 SCK   - ISP
 * 20 Vcc   - Vcc
 *
 *    NSM4202
 * ---------------------------------
 *  1 /OE   - PD0
 *  2 DATA  - PD2
 *  3 CLK   - PD1
 *  4 Vcc1  - Vcc
 *  6 GND   - GND
 *  7 Vcc2  - Vcc
 *  8 Aux1  - LED green  "Ready"   (data bit #34)
 *  9 Aux2  - LED yellow "Running" (data bit #33)
 * 10 Aux3  - LED red    "Done"    (data bit #8)
 * 11 Aux4
 * 12 Aux5
 *
 */

#ifndef HAL_H
#define HAL_H


/* hardware dependent macros */

#define oe_pin          0
#define clk_pin         1
#define data_pin        2
#define bulb_pin        4
#define enc_pin_a       0
#define enc_pin_b       1
#define button_pin      6

#define oe_hi()         PORTD |=  _BV(oe_pin)
#define oe_lo()         PORTD &= ~_BV(oe_pin)
#define clk_hi()        PORTD |=  _BV(clk_pin)
#define clk_lo()        PORTD &= ~_BV(clk_pin)
#define data_hi()       PORTD |=  _BV(data_pin)
#define data_lo()       PORTD &= ~_BV(data_pin)
#define bulb_on()       PORTD |=  _BV(bulb_pin)
#define bulb_off()      PORTD &= ~_BV(bulb_pin)

#define wait()          _delay_us(1)

#define phase_A         ( PINB & _BV(enc_pin_a) )
#define phase_B         ( PINB & _BV(enc_pin_b) )
#define sample_button   ( PIND & _BV(button_pin) ? 0 : 1 )


#endif /* HAL_H */
